#
# @license
# Copyright (c) 2020 XGDFalcon®. All Rights Reserved.
#
#
# XGDFalcon LLC retains all intellectual property rights to the code
# distributed as part of the Control Point System Software (CPSS) package.
# 

"""
This python module provides the models for the video vault application.

Written by Larry Latouf (xgdfalcon@gmail.com)
"""

from django.test import TestCase
from django.test.client import RequestFactory
from .models.client import VimeoClientOption
import os

CLIENT_SECRET = os.environ['CLIENT_SECRET'] 
CLIENT_ID = os.environ['CLIENT_ID'] 
ACCESS_TOKEN = os.environ['ACCESS_TOKEN'] 
USER_ID = os.environ['USER_ID'] 
PROJECT_ID = os.environ['PROJECT_ID'] 

class VimeoDjangoTestCase(TestCase):
    def setUp(self):
        VimeoClientOption.objects.create(
            vimeo_user_id=USER_ID,
            vimeo_client_id=CLIENT_ID,
            vimeo_client_secret=CLIENT_SECRET,
            vimeo_access_token=ACCESS_TOKEN,
            vimeo_project_id=PROJECT_ID)

    def test_retrieve_project(self):
        # response = self.client.get('/')
        collection = VimeoClientOption.objects.get(vimeo_project_id=PROJECT_ID)
        result = collection.get_folder_contents()
        print(result)
        

    def test_get_project(self):
        rf = RequestFactory()
        get_request = rf.get('project/'+PROJECT_ID)
        print(get_request)
        




#
# @license
# Copyright (c) 2020 XGDFalcon®. All Rights Reserved.
#
#
# XGDFalcon LLC retains all intellectual property rights to the code
# distributed as part of the Control Point System Software (CPSS) package.
# 

"""
This python module provides...

Written by Larry Latouf (xgdfalcon@gmail.com)
"""

from django.apps import AppConfig

class CPSSVimeoConfig(AppConfig):
    name = 'vimeo-django'
    verbose_name = "CPSS Vimeo - Django"



#
# @license
# Copyright (c) 2020 XGDFalcon®. All Rights Reserved.
#
#
# XGDFalcon LLC retains all intellectual property rights to the code
# distributed as part of the Control Point System Software (CPSS) package.
#

"""
This python module provides...

Written by Larry Latouf (xgdfalcon@gmail.com)
"""

from django.shortcuts import render, get_object_or_404
from django.http import HttpResponse, HttpResponseRedirect
from django.template import loader
from django.contrib.auth.decorators import login_required
from .models.client import VimeoClientOption

# @login_required
def get_project(request, project_id):
    collection_instance = get_object_or_404(VimeoClientOption, vimeo_project_id=project_id)
    return HttpResponse(collection_instance.get_folder_contents())




# Generated by Django 3.0.2 on 2020-01-10 23:18

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='VimeoClientOption',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, verbose_name='ID')),
                ('vimeo_user_id', models.CharField(default='', max_length=100, verbose_name='Vimeo User ID')),
                ('vimeo_client_id', models.CharField(default='', max_length=100, verbose_name='Vimeo Client ID')),
                ('vimeo_client_secret', models.CharField(default='', max_length=100, verbose_name='Vimeo Client Secret')),
                ('vimeo_access_token', models.CharField(default='', max_length=100, verbose_name='Vimeo Access Token')),
                ('vimeo_project_id', models.CharField(default='', max_length=100, unique=True, verbose_name='Vimeo Project ID/Folder ID')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site')),
            ],
            options={
                'verbose_name': 'CPSS Vimeo Client Setting',
                'verbose_name_plural': 'CPSS Vimeo Client Settings',
                'db_table': 'vimeo_django_settings',
            },
        ),
    ]



#
# @license
# Copyright (c) 2020 XGDFalcon®. All Rights Reserved.
#
#
# XGDFalcon LLC retains all intellectual property rights to the code
# distributed as part of the Control Point System Software (CPSS) package.
#

"""
ASGI config for vimeo project.

It exposes the ASGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/howto/deployment/asgi/
"""

import os

from django.core.asgi import get_asgi_application

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'vimeo-django.settings')

application = get_asgi_application()
